<?php
/**
 * Implements an optional custom header for Twenty Twelve.
 * See http://codex.wordpress.org/Custom_Headers
 *
 * @package WordPress
 * @subpackage Twenty_Twelve
 * @since Twenty Twelve 1.0
 */

/**
 * Sets up the WordPress core custom header arguments and settings.
 *
 * @uses add_theme_support() to register support for 3.4 and up.
 * @uses styledthemes_header_style() to style front-end.
 * @uses styledthemes_admin_header_style() to style wp-admin form.
 * @uses styledthemes_admin_header_image() to add custom markup to wp-admin form.
 *
 * @since Twenty Twelve 1.0
 */
function styledthemes_custom_header_setup() {
	$args = array(
		// Text color and image (empty to use none).
		'default-image'          => '',

		// Set height and width, with a maximum value for the width.
		'height'                 => 340,
		'width'                  => 1920,
		'max-width'              => 2650,

		// Support flexible height and width.
		'flex-height'            => true,
		'flex-width'             => true,

		// Random image rotation off by default.
		'random-default'         => false,

		// Callbacks for styling the header and the admin preview.
		'admin-preview-callback' => 'styledthemes_admin_header_image',
	);

	add_theme_support( 'custom-header', $args );
}
add_action( 'after_setup_theme', 'styledthemes_custom_header_setup' );



/**
 * Outputs markup to be displayed on the Appearance > Header admin panel.
 * This callback overrides the default markup displayed there.
 *
 * @since Twenty Twelve 1.0
 */
function styledthemes_admin_header_image() {
	?>
	<div id="headimg">
		
		<?php $header_image = get_header_image();
		if ( ! empty( $header_image ) ) : ?>
			<img src="<?php echo esc_url( $header_image ); ?>" class="header-image" width="<?php echo get_custom_header()->width; ?>" height="<?php echo get_custom_header()->height; ?>" alt="" />
		<?php endif; ?>
	</div>
<?php }